# -*- coding: utf-8 -*-

from .institute import Institute
from .phenotype_term import HpoTerm
from .user import User
